"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.collectFlow = void 0;
const tslib_1 = require("tslib");
const loggin_1 = require("../../../../core/loggin");
const puppeteer = require("puppeteer");
const path_1 = require("path");
const lighthouse_1 = require("../../../../hacky-things/lighthouse");
const dryRun_1 = require("../../../../commands/collect/options/dryRun");
const user_flow_mock_1 = require("./user-flow.mock");
const budgets_1 = require("../../../assert/utils/budgets");
const cli_mode_1 = require("../../../../global/cli-mode/cli-mode");
function collectFlow(cliOption, userFlowProvider) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        let { path, 
        // object containing the LH setting for budgets
        flowOptions: providerFlowOptions, interactions, launchOptions } = userFlowProvider;
        const { config } = providerFlowOptions, rest = tslib_1.__rest(providerFlowOptions, ["config"]);
        const flowOptions = Object.assign(Object.assign({}, rest), { config: parseUserFlowOptionsConfig(providerFlowOptions.config) });
        // object containing the options for puppeteer/chromium
        launchOptions = launchOptions || {
            // has to be false to run in the CI because of a bug :(
            // https://github.com/puppeteer/puppeteer/issues/8148
            headless: false,
            // hack for dryRun => should get fixed inside user flow in future
            defaultViewport: { isMobile: true, isLandscape: false, width: 800, height: 600 }
        };
        // @TODO consider CI vs dev mode => headless, openReport, persist etc
        if ((0, cli_mode_1.detectCliMode)() !== 'DEFAULT') {
            (0, loggin_1.logVerbose)(`Set headless to true as we are running in ${(0, cli_mode_1.detectCliMode)()} mode`);
            launchOptions.headless = true;
        }
        const browser = yield puppeteer.launch(launchOptions);
        const page = yield browser.newPage();
        (0, loggin_1.logVerbose)(`Collect: ${flowOptions.name} from URL ${cliOption.url}`);
        (0, loggin_1.logVerbose)(`User-flow path: ${(0, path_1.normalize)(path)}`);
        let start = Date.now();
        const flow = !(0, dryRun_1.get)() ? yield (0, lighthouse_1.startFlow)(page, flowOptions) : new user_flow_mock_1.UserFlowMock(page, flowOptions);
        // run custom interactions
        yield interactions({ flow, page, browser, collectOptions: cliOption });
        (0, loggin_1.logVerbose)(`Duration: ${flowOptions.name}: ${(Date.now() - start) / 1000}`);
        yield browser.close();
        return flow;
    });
}
exports.collectFlow = collectFlow;
function parseUserFlowOptionsConfig(flowOptionsConfig) {
    var _a, _b;
    flowOptionsConfig = flowOptionsConfig || {};
    // @ts-ignore
    (flowOptionsConfig === null || flowOptionsConfig === void 0 ? void 0 : flowOptionsConfig.extends) || (flowOptionsConfig.extends = 'lighthouse:default');
    // if budgets are given
    if ((_a = flowOptionsConfig === null || flowOptionsConfig === void 0 ? void 0 : flowOptionsConfig.settings) === null || _a === void 0 ? void 0 : _a.budgets) {
        (0, loggin_1.logVerbose)('format given budgets');
        let budgets = (_b = flowOptionsConfig === null || flowOptionsConfig === void 0 ? void 0 : flowOptionsConfig.settings) === null || _b === void 0 ? void 0 : _b.budgets;
        budgets && (budgets = Array.isArray(budgets) ? budgets : (0, budgets_1.readBudgets)(budgets));
        flowOptionsConfig.settings.budgets = budgets;
    }
    return flowOptionsConfig;
}
//# sourceMappingURL=collect-flow.js.map