"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.persistFlow = void 0;
const tslib_1 = require("tslib");
const generate_reports_1 = require("../../processes/generate-reports");
const loggin_1 = require("../../../../core/loggin");
const path_1 = require("path");
const file_1 = require("../../../../core/file");
const fs_1 = require("fs");
function persistFlow(flow, name, { outPath, format }) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        if (!format.length) {
            format = ['stdout'];
        }
        const jsonReport = yield flow.createFlowResult();
        const results = [];
        if (format.includes('json')) {
            results.push({ format: 'json', out: JSON.stringify(jsonReport) });
        }
        let mdReport = undefined;
        if (format.includes('md')) {
            mdReport = (0, generate_reports_1.generateMdReport)(jsonReport);
            results.push({ format: 'md', out: mdReport });
        }
        if (format.includes('stdout')) {
            mdReport = mdReport || (0, generate_reports_1.generateMdReport)(jsonReport);
            (0, loggin_1.log)(mdReport + '');
        }
        if (format.includes('html')) {
            const htmlReport = yield flow.generateReport();
            results.push({ format: 'html', out: htmlReport });
        }
        if (!(0, fs_1.existsSync)(outPath)) {
            try {
                (0, fs_1.mkdirSync)(outPath, { recursive: true });
            }
            catch (e) {
                // @TODO use a constant instead of a string e.g. `OUT_PATH_NO_DIR_ERROR(dir)`
                throw new Error(`outPath: ${outPath} is no directory`);
            }
        }
        const fileNames = results.map((result) => {
            const fileName = (0, path_1.join)(outPath, `${(0, file_1.toFileName)(name)}.${result.format}`);
            (0, file_1.writeFile)(fileName, result.out);
            (0, loggin_1.logVerbose)(`Report path: ${fileName}.`);
            return fileName;
        });
        return fileNames;
    });
}
exports.persistFlow = persistFlow;
//# sourceMappingURL=persist-flow.js.map