"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initCommand = void 0;
const tslib_1 = require("tslib");
const loggin_1 = require("../../core/loggin");
const options_1 = require("./options");
const utils_1 = require("./utils");
const collect_rc_json_1 = require("./processes/collect-rc-json");
const prompt_1 = require("../../core/prompt");
const behaviors_1 = require("../../core/processing/behaviors");
const file_1 = require("../../core/file");
const constants_1 = require("./constants");
const update_rc_json_1 = require("./processes/update-rc-json");
const fs_1 = require("fs");
exports.initCommand = {
    command: 'init',
    description: 'Setup .user-flowrc.json',
    builder: (y) => y.options(options_1.INIT_OPTIONS),
    module: {
        handler: (argv) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            (0, loggin_1.logVerbose)(`run "init" as a yargs command`);
            const cfg = (0, utils_1.getInitCommandOptionsFromArgv)(argv);
            (0, loggin_1.logVerbose)('Init options: ', cfg);
            const exampleName = 'basic-navigation';
            const userflowIsNotCreated = (cfg) => Promise.resolve(cfg ? (0, file_1.readFile)((0, utils_1.getExamplePathDest)(exampleName, cfg.collect.ufPath)) === '' : false);
            yield (0, behaviors_1.run)([
                collect_rc_json_1.collectRcJson,
                update_rc_json_1.updateRcJson,
                (0, prompt_1.askToSkip)('Setup user flow', (cfg) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
                    const ufPath = cfg.collect.ufPath;
                    // DX create directory if it does ot exist
                    try {
                        (0, fs_1.readdirSync)(ufPath);
                    }
                    catch (e) {
                        (0, fs_1.mkdirSync)(ufPath, { recursive: true });
                    }
                    (0, utils_1.addUserFlow)(exampleName, ufPath);
                    return Promise.resolve(cfg);
                }), {
                    precondition: userflowIsNotCreated
                })
            ])(cfg);
            (0, loggin_1.log)(constants_1.SETUP_CONFIRM_MESSAGE);
            // @TODO move to constants
            (0, loggin_1.log)('To execute a user flow run `npx user-flow` or `npx user-flow collect`');
        })
    }
};
//# sourceMappingURL=index.js.map